==> vue-checkbox-2.8.0.tgz: package/lib/pc.js <==
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/checkbox/vue";
import { defineComponent, props, setup as _setup } from "@dftvue2-opentiny/vue-common";
import "@dftvue2-opentiny/vue-theme/checkbox/index.css";
import { iconHalfselect, iconCheckedSur, iconCheck } from "@dftvue2-opentiny/vue-icon";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  emits: ["change", "update:modelValue", "complete"],
  props: [].concat(props, ["modelValue", "text", "events", "label", "indeterminate", "disabled", "checked", "name", "trueLabel", "falseLabel", "id", "controls", "size", "border", "validateEvent", "displayOnly"]),
  components: {
    IconHalfselect: iconHalfselect(),
    IconCheckedSur: iconCheckedSur(),
    IconCheck: iconCheck()
  },
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("label", _vm._b({
    staticClass: "tiny-checkbox",
    class: [_vm.border && _vm.state.checkboxSize ? "tiny-checkbox--" + _vm.state.checkboxSize : "", {
      "is-disabled": _vm.state.isDisabled || _vm.state.isDisplayOnly
    }, {
      "is-bordered": _vm.border
    }, {
      "is-checked": _vm.state.isChecked
    }, {
      "is-group-display-only": _vm.state.isGroupDisplayOnly
    }, {
      "is-display-only": _vm.state.isDisplayOnly
    }],
    attrs: {
      "id": _vm.id,
      "tabindex": "-1"
    }
  }, "label", _vm.a(_vm.$attrs, ["class", "style", "onClick"], true), false), [_c("span", {
    staticClass: "tiny-checkbox__input",
    class: {
      "is-disabled": _vm.state.isDisabled || _vm.state.isDisplayOnly,
      "is-checked": _vm.state.isChecked,
      "is-indeterminate": _vm.indeterminate,
      "is-focus": _vm.state.focus
    },
    attrs: {
      "role": _vm.indeterminate ? "checkbox" : void 0,
      "aria-checked": _vm.indeterminate ? "mixed" : false
    }
  }, [_c("span", {
    staticClass: "tiny-checkbox__inner",
    attrs: {
      "tabindex": "1"
    }
  }, [_vm.indeterminate ? _c("icon-halfselect", {
    staticClass: "tiny-svg-size icon-halfselect"
  }) : _vm.state.isChecked ? _c("icon-checked-sur", {
    staticClass: "tiny-svg-size icon-checked-sur"
  }) : _c("icon-check", {
    staticClass: "tiny-svg-size icon-check"
  })], 1), _vm.trueLabel || _vm.falseLabel ? _c("input", {
    directives: [{
      name: "model",
      rawName: "v-model",
      value: _vm.state.model,
      expression: "state.model"
    }],
    staticClass: "tiny-checkbox__original",
    attrs: {
      "type": "checkbox",
      "aria-hidden": _vm.indeterminate ? "true" : "false",
      "name": _vm.name,
      "disabled": _vm.state.isDisabled || _vm.state.isDisplayOnly,
      "true-value": _vm.trueLabel,
      "false-value": _vm.falseLabel
    },
    domProps: {
      "checked": Array.isArray(_vm.state.model) ? _vm._i(_vm.state.model, null) > -1 : _vm._q(_vm.state.model, _vm.trueLabel)
    },
    on: {
      "change": [function($event) {
        var $$a = _vm.state.model, $$el = $event.target, $$c = $$el.checked ? _vm.trueLabel : _vm.falseLabel;
        if (Array.isArray($$a)) {
          var $$v = null, $$i = _vm._i($$a, $$v);
          if ($$el.checked) {
            $$i < 0 && _vm.$set(_vm.state, "model", $$a.concat([$$v]));
          } else {
            $$i > -1 && _vm.$set(_vm.state, "model", $$a.slice(0, $$i).concat($$a.slice($$i + 1)));
          }
        } else {
          _vm.$set(_vm.state, "model", $$c);
        }
      }, _vm.handleChange],
      "focus": function focus($event) {
        _vm.state.focus = true;
      },
      "blur": function blur($event) {
        _vm.state.focus = false;
      },
      "click": function click($event) {
        $event.stopPropagation();
      }
    }
  }) : _c("input", {
    directives: [{
      name: "model",
      rawName: "v-model",
      value: _vm.state.model,
      expression: "state.model"
    }],
    staticClass: "tiny-checkbox__original",
    attrs: {
      "type": "checkbox",
      "aria-hidden": _vm.indeterminate ? "true" : "false",
      "disabled": _vm.state.isDisabled || _vm.state.isDisplayOnly,
      "name": _vm.name
    },
    domProps: {
      "value": _vm.label,
      "checked": Array.isArray(_vm.state.model) ? _vm._i(_vm.state.model, _vm.label) > -1 : _vm.state.model
    },
    on: {
      "change": [function($event) {
        var $$a = _vm.state.model, $$el = $event.target, $$c = $$el.checked ? true : false;
        if (Array.isArray($$a)) {
          var $$v = _vm.label, $$i = _vm._i($$a, $$v);
          if ($$el.checked) {
            $$i < 0 && _vm.$set(_vm.state, "model", $$a.concat([$$v]));
          } else {
            $$i > -1 && _vm.$set(_vm.state, "model", $$a.slice(0, $$i).concat($$a.slice($$i + 1)));
          }
        } else {
          _vm.$set(_vm.state, "model", $$c);
        }
      }, _vm.handleChange],
      "focus": function focus($event) {
        _vm.state.focus = true;
      },
      "blur": function blur($event) {
        _vm.state.focus = false;
      },
      "click": function click($event) {
        $event.stopPropagation();
      }
    }
  })]), _vm.slots.default && _vm.slots.default() || _vm.state.isShowText ? _c("span", {
    staticClass: "tiny-checkbox__label tiny-checkbox-display-only"
  }, [_vm._t("default", function() {
    return [_vm._v(_vm._s(_vm.state.showText))];
  })], 2) : _vm._e()]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  pc as default
};

==> vue-checkbox-2.21.0.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/checkbox/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import '@opentinyvue/vue-theme/checkbox/index.css';
import { iconHalfselect, iconCheckedSur, iconCheck } from '@opentinyvue/vue-icon';
import { AutoTip } from '@opentinyvue/vue-directive';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  // tiny 新增。 renderless中，没有emit('click')的地方。 此处勿声明，否则会造成丢失click事件。
  emits: ["update:modelValue", "change", "complete"],
  directives: {
    AutoTip
  },
  props: [].concat(props, ["modelValue", "text", "events", "label", "indeterminate", "disabled", "checked", "name", "trueLabel", "falseLabel", "id", "controls", "size", "border", "validateEvent", "displayOnly", "shape", "tabindex"]),
  components: {
    IconHalfselect: iconHalfselect(),
    IconCheckedSur: iconCheckedSur(),
    IconCheck: iconCheck()
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("label", _vm._b({
    staticClass: "tiny-checkbox",
    class: [_vm.border && _vm.state.checkboxSize ? "tiny-checkbox--" + _vm.state.checkboxSize : "", {
      "is-disabled": _vm.state.isDisabled || _vm.state.isDisplayOnly
    }, {
      "is-bordered": _vm.border
    }, {
      "is-checked": _vm.state.isChecked
    }, {
      "is-group-display-only": _vm.state.isGroupDisplayOnly
    }, {
      "is-display-only": _vm.state.isDisplayOnly
    }, {
      "is-filter": _vm.state.shape === "filter"
    }],
    attrs: {
      "id": _vm.id,
      "tabindex": "-1"
    }
  }, "label", _vm.a(_vm.$attrs, ["class", "style", "onClick"], true), false), [_c("span", {
    staticClass: "tiny-checkbox__input",
    class: {
      "is-disabled": _vm.state.isDisabled || _vm.state.isDisplayOnly,
      "is-checked": _vm.state.isChecked,
      "is-indeterminate": _vm.indeterminate,
      "is-focus": _vm.state.focus
    },
    attrs: {
      "role": _vm.indeterminate ? "checkbox" : void 0,
      "aria-checked": _vm.indeterminate ? "mixed" : false
    }
  }, [_vm.trueLabel || _vm.falseLabel ? _c("input", {
    directives: [{
      name: "model",
      rawName: "v-model",
      value: _vm.state.model,
      expression: "state.model"
    }],
    staticClass: "tiny-checkbox__original",
    attrs: {
      "type": "checkbox",
      "tabindex": _vm.tabindex,
      "aria-hidden": _vm.indeterminate ? "true" : "false",
      "name": _vm.name,
      "disabled": _vm.state.isDisabled || _vm.state.isDisplayOnly,
      "true-value": _vm.trueLabel,
      "false-value": _vm.falseLabel
    },
    domProps: {
      "checked": Array.isArray(_vm.state.model) ? _vm._i(_vm.state.model, null) > -1 : _vm._q(_vm.state.model, _vm.trueLabel)
    },
    on: {
      "change": [function($event) {
        var $$a = _vm.state.model, $$el = $event.target, $$c = $$el.checked ? _vm.trueLabel : _vm.falseLabel;
        if (Array.isArray($$a)) {
          var $$v = null, $$i = _vm._i($$a, $$v);
          if ($$el.checked) {
            $$i < 0 && _vm.$set(_vm.state, "model", $$a.concat([$$v]));
          } else {
            $$i > -1 && _vm.$set(_vm.state, "model", $$a.slice(0, $$i).concat($$a.slice($$i + 1)));
          }
        } else {
          _vm.$set(_vm.state, "model", $$c);
        }
      }, function($event) {
        $event.stopPropagation();
        return _vm.handleChange.apply(null, arguments);
      }],
      "focus": function focus($event) {
        _vm.state.focus = true;
      },
      "blur": function blur($event) {
        _vm.state.focus = false;
      },
      "click": function click($event) {
        $event.stopPropagation();
      }
    }
  }) : _c("input", {
    directives: [{
      name: "model",
      rawName: "v-model",
      value: _vm.state.model,
      expression: "state.model"
    }],
    staticClass: "tiny-checkbox__original",
    attrs: {
      "type": "checkbox",
      "tabindex": _vm.tabindex,
      "aria-hidden": _vm.indeterminate ? "true" : "false",
      "disabled": _vm.state.isDisabled || _vm.state.isDisplayOnly,
      "name": _vm.name
    },
    domProps: {
      "value": _vm.label,
      "checked": Array.isArray(_vm.state.model) ? _vm._i(_vm.state.model, _vm.label) > -1 : _vm.state.model
    },
    on: {
      "change": [function($event) {
        var $$a = _vm.state.model, $$el = $event.target, $$c = $$el.checked ? true : false;
        if (Array.isArray($$a)) {
          var $$v = _vm.label, $$i = _vm._i($$a, $$v);
          if ($$el.checked) {
            $$i < 0 && _vm.$set(_vm.state, "model", $$a.concat([$$v]));
          } else {
            $$i > -1 && _vm.$set(_vm.state, "model", $$a.slice(0, $$i).concat($$a.slice($$i + 1)));
          }
        } else {
          _vm.$set(_vm.state, "model", $$c);
        }
      }, function($event) {
        $event.stopPropagation();
        return _vm.handleChange.apply(null, arguments);
      }],
      "focus": function focus($event) {
        _vm.state.focus = true;
      },
      "blur": function blur($event) {
        _vm.state.focus = false;
      },
      "click": function click($event) {
        $event.stopPropagation();
      }
    }
  }), _c("span", {
    staticClass: "tiny-checkbox__inner"
  }, [_vm.indeterminate && _vm.state.shape !== "filter" ? _c("icon-halfselect", {
    staticClass: "tiny-svg-size icon-halfselect"
  }) : _vm.state.isChecked ? _c("icon-checked-sur", {
    staticClass: "tiny-svg-size icon-checked-sur"
  }) : _c("icon-check", {
    staticClass: "tiny-svg-size icon-check"
  })], 1)]), _vm.slots.default && _vm.slots.default() || _vm.state.isShowText ? _c("span", {
    directives: [{
      name: "auto-tip",
      rawName: "v-auto-tip"
    }],
    staticClass: "tiny-checkbox__label tiny-checkbox-display-only"
  }, [_vm._t("default", function() {
    return [_vm._v(_vm._s(_vm.state.showText))];
  })], 2) : _vm._e()]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
